# GrandExchange  [![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square)](http://makeapullrequest.com) [![GPL Licence](https://badges.frapsoft.com/os/gpl/gpl.svg?v=103)](https://opensource.org/licenses/GPL-3.0/) [![Canadian Mental Health Association](https://i.imgur.com/GvXBeY4.png)](https://cmha.ca/donate)
A python wrapper for OSBuddy exchange data. This will provide up to date an accurate grand exchange data for OldSchool Runescape.

# Documentation
Please refer to the [wiki](https://github.com/ejedev/GrandExchange/wiki) page for documentation.

# Setup
Install the module with `pip install GrandExchange`

Import the module with `from GrandExchange import GrandExchange`

A class can be created with `GrandExchange.Exchange()`
